@@ -23,6 +23,21 @@ Mail::DKIM::DkSignature - represents a DomainKeys-Signature header
 
 =head1 CONSTRUCTORS
 
+=head2 new()
+
+Create a new DomainKey signature from parameters
+
+  my $signature = Mail::DKIM::DkSignature->new(
+                      [ Algorithm => "rsa-sha1", ]
+                      [ Signature => $base64, ]
+                      [ Method => "simple", ]
+                      [ Domain => "example.org", ]
+                      [ Headers => "from:subject:date:message-id", ]
+                      [ Query => "dns", ]
+                      [ Selector => "alpha", ]
+                      [ Key => $private_key, ]
+                  );
+
 =cut
 
 sub new {
@@ -38,13 +53,16 @@ sub new {
 	$self->headerlist($prms{'Headers'});
 	$self->protocol($prms{'Query'} || "dns");
 	$self->selector($prms{'Selector'});
+	$self->key($prms{'Key'}) if defined $prms{'Key'};
 
 	return $self;
 }
 
-=head2 parse() - create a new signature from a DomainKey-Signature header
+=head2 parse()
 
-  my $sig = parse Mail::DKIM::DkSignature(
+Create a new signature from a DomainKey-Signature header
+
+  my $sig = Mail::DKIM::DkSignature->parse(
                   "DomainKey-Signature: a=rsa-sha1; b=yluiJ7+0=; c=nofws"
             );
 
@@ -52,7 +70,7 @@ Constructs a signature by parsing the provided DomainKey-Signature header
 content. You do not have to include the header name
 (i.e. "DomainKey-Signature:")
 but it is recommended, so the header name can be preserved and returned
-the same way in as_string().
+the same way in L</"as_string()">.
 
 Note: The input to this constructor is in the same format as the output
 of the as_string method.
@@ -89,7 +107,9 @@ sub parse
 
 =cut
 
-=head2 as_string() - the signature header as a string
+=head2 as_string()
+
+Convert the signature header as a string.
 
   print $signature->as_string . "\n";
 
@@ -117,7 +137,9 @@ sub body_hash
 	croak "body_hash not implemented";
 }
 
-=head2 algorithm() - get or set the algorithm (a=) field
+=head2 algorithm()
+
+Get or set the algorithm (a=) field
 
 The algorithm used to generate the signature.
 Defaults to "rsa-sha1", an RSA-signed SHA-1 digest.
@@ -133,10 +155,13 @@ sub algorithm
 		$self->set_tag("a", shift);
 	}
 
-	return lc $self->get_tag("a") || 'rsa-sha1';
+	my $a = $self->get_tag("a");
+	return defined $a && $a ne '' ? lc $a : 'rsa-sha1';
 }	
 
-=head2 canonicalization() - get or set the canonicalization (c=) field
+=head2 canonicalization()
+
+Get or set the canonicalization (c=) field.
 
   $signature->canonicalization("nofws");
   $signature->canonicalization("simple");
@@ -167,7 +192,9 @@ sub DEFAULT_PREFIX
 	return "DomainKey-Signature:";
 }
 
-=head2 domain() - get or set the domain (d=) field
+=head2 domain()
+
+Get or set the domain (d=) field.
 
   my $d = $signature->domain;          # gets the domain value
   $signature->domain("example.org");   # sets the domain value
@@ -186,7 +213,8 @@ sub domain
 		$self->set_tag("d", shift);
 	}
 
-	return lc $self->get_tag("d");
+	my $d = $self->get_tag("d");
+	return defined $d ? lc $d : undef;
 }	
 
 sub expiration
@@ -209,17 +237,19 @@ sub check_canonicalization
 	return 1;
 }
 
-# checks whether the protocol found on this subject is valid for
-# fetching the public key
-# returns a true value if protocol is "dns", false otherwise
+# Returns a filtered list of protocols that can be used to fetch the
+# public key corresponding to this signature. An empty list means that
+# all designated protocols are unrecognized.
+# Note: at this time, the only recognized protocol for DomainKey
+# signatures is "dns".
 #
 sub check_protocol
 {
 	my $self = shift;
 
 	my $protocol = $self->protocol;
-	return unless $protocol;
-	return ($protocol eq "dns");
+	return "dns/txt" if $protocol && $protocol eq "dns";
+	return;
 }
 
 sub check_version
@@ -250,7 +280,9 @@ sub hash_algorithm
 	return $algorithm eq "rsa-sha1" ? "sha1" : undef;
 }
 
-=head2 headerlist() - get or set the signed header fields (h=) field
+=head2 headerlist()
+
+Get or set the signed header fields (h=) field.
 
   $signature->headerlist("a:b:c");
 
@@ -270,13 +302,15 @@ In list context, the header field names will be returned as a list.
 #sub headerlist
 # is in Signature.pm
 
-=head2 identity() - get the signing identity
+=head2 identity()
+
+Get the signing identity.
 
   my $i = $signature->identity;
 
 In DomainKey signatures, the signing identity is the first address
 found in the Sender header or the From header. This field is
-populated by the Verifier when processing a DomainKey signature.
+populated by the L<Verifier|Mail::DKIM::Verifier> when processing a DomainKey signature.
 
 =cut
 
@@ -287,7 +321,9 @@ sub identity
 	return $self->{dk_identity};
 }
 
-=head2 identity_source() - determine which header had the identity
+=head2 identity_source()
+
+Determine which header had the identity.
 
   my $source = $signature->identity_source;
 
@@ -325,7 +361,9 @@ sub method
 	croak "method not implemented (use canonicalization instead)";
 }	
 
-=head2 protocol() - get or set the query methods (q=) field
+=head2 protocol()
+
+Get or set the query methods (q=) field.
 
 A colon-separated list of query methods used to retrieve the public
 key (default is "dns").
@@ -343,7 +381,9 @@ sub protocol {
 	return !defined($self->get_tag("q")) ? 'dns' : $self->get_tag("q");
 }	
 
-=head2 selector() - get or set the selector (s=) field
+=head2 selector()
+
+Get or set the selector (s=) field.
 
 The selector subdivides the namespace for the "d=" (domain) tag.
 
@@ -351,7 +391,9 @@ The selector subdivides the namespace for the "d=" (domain) tag.
 
 # same as parent class
 
-=head2 signature() - get or set the signature data (b=) field
+=head2 signature()
+
+Get or set the signature data (b=) field.
 
 The signature data. Whitespace is automatically stripped from the
 returned value.
@@ -380,7 +422,7 @@ Jason Long, E<lt>jlong@messiah.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+Copyright (C) 2006-2007,2010 by Messiah College
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
