@@ -66,17 +66,17 @@ sub load
 
 	if ($prms{'Data'}) {
 		$self->{'DATA'} = $prms{'Data'};
-	} elsif ($prms{'File'}) {	
+	} elsif (defined $prms{'File'}) {	
 		my @data;
-		open FILE, "<", $prms{'File'}
+		open my $file, "<", $prms{'File'}
 			or die "Error: cannot read $prms{File}: $!\n";
-		while (<FILE>) {
-			chomp;
-			/^---/ and
-				next;
-			push @data, $_;
+		while (my $line = <$file>) {
+			chomp $line;
+                        next if $line =~ /^---/;
+                        push @data, $line;
 		}
 		$self->{'DATA'} = join '', @data;
+                close $file;
 	} elsif ($prms{'Cork'}) {
 		$self->{'CORK'} = $prms{'Cork'};
 	} else {
@@ -138,6 +138,7 @@ sub convert {
 	return 1;
 }
 
+#deprecated
 sub sign
 {
 	my $self = shift;
@@ -147,6 +148,7 @@ sub sign
 	return $self->cork->sign($mail);
 }
 
+#deprecated- use sign_digest() instead
 sub sign_sha1_digest
 {
 	my $self = shift;
@@ -154,6 +156,20 @@ sub sign_sha1_digest
 	return $self->sign_digest("SHA-1", $digest);
 }
 
+=head2 sign_digest()
+
+Cryptographically sign the given message digest.
+
+  $key->sign_digest("SHA-1", sha1("my message text"));
+
+The first parameter is the name of the digest: one of "SHA-1", "SHA-256".
+
+The second parameter is the message digest as a binary string.
+
+The result should be the signed digest as a binary string.
+
+=cut
+
 sub sign_digest
 {
 	my $self = shift;
